package com.sundot.airport.system.service;

import java.util.List;

import com.sundot.airport.system.domain.BaseProject;
import com.sundot.airport.system.domain.vo.CheckProjectItemVo;

/**
 * 检查项目Service接口
 *
 * @author ruoyi
 * @date 2025-07-11
 */
public interface IBaseProjectService {
    /**
     * 查询检查项目
     *
     * @param id 检查项目主键
     * @return 检查项目
     */
    public BaseProject selectBaseProjectById(Long id);

    /**
     * 查询检查项目列表
     *
     * @param baseProject 检查项目
     * @return 检查项目集合
     */
    public List<BaseProject> selectBaseProjectList(BaseProject baseProject);

    /**
     * 新增检查项目
     *
     * @param baseProject 检查项目
     * @return 结果
     */
    public int insertBaseProject(BaseProject baseProject);

    /**
     * 修改检查项目
     *
     * @param baseProject 检查项目
     * @return 结果
     */
    public int updateBaseProject(BaseProject baseProject);

    /**
     * 批量删除检查项目
     *
     * @param ids 需要删除的检查项目主键集合
     * @return 结果
     */
    public int deleteBaseProjectByIds(Long[] ids);

    /**
     * 删除检查项目信息
     *
     * @param id 检查项目主键
     * @return 结果
     */
    public int deleteBaseProjectById(Long id);

    /**
     * 查询检查项目列表
     *
     * @param categoryCode 分类编码
     * @return 检查项目列表
     */
    public List<BaseProject> selectProjectListByCategoryCode(String categoryCode);

    /**
     * 查询检查项目列表
     *
     * @param checkLevel 检查级别
     * @return 检查项目列表
     */
    public List<CheckProjectItemVo> listByCheckLevel(String checkLevel);
}
